@@ -6,12 +6,11 @@ import unicodedata
 import string
 from lxml.cssselect import CSSSelector
 
-
-class Parser:
+class Parser(object):
     """ Simple wrapper around lxml object """
-    def __init__(self, element):
+    def __init__(self, element, encoding="utf8"):
         self.element = element
-        self.encoding = "utf8"
+        self.encoding = encoding
 
     def __call__(self, selector):
         """ Simple access to CSSSelector through obj(selector) """
@@ -19,14 +18,17 @@ class Parser:
         return [Parser(element) for element in result]
     css = __call__
 
-    def get(self, selector):
+    def get(self, selector, index=0, default=None):
         """ Get first element from CSSSelector """
         elements = self(selector)
         if elements:
-            return elements[0]
-        return None
+            try:
+                return elements[index]
+            except (IndexError):
+                pass
+        return default
 
-    def html(self, encoding="utf8"):
+    def html(self):
         """ Return html of element """
         return lxml.html.tostring(self.element, encoding=self.encoding)
 
@@ -38,8 +40,8 @@ class Parser:
         result = []
         for element in self.xpath('child::node()'):
             if isinstance(element, Parser):
-                childrens = element.parse(func, *args, **kwargs)
-                element_result = func(element, childrens, *args, **kwargs)
+                children = element.parse(func, *args, **kwargs)
+                element_result = func(element, children, *args, **kwargs)
                 if element_result:
                     result.append(element_result)
             else:
@@ -75,9 +77,20 @@ class Parser:
             return self._wrap_result(result)
         else:
             return result
+    
+    def __setattr__(self, name, value):
+        """ Easy access to attribute modification """
+        # Simple hack for break setattr recursion
+        if name in ['element', 'encoding']:
+            super(Parser, self).__setattr__(name, value)
+        if name in self.element.attrib:
+            self.element.attrib[name] = value
+    
+    def __nonzero__(self):
+        return self.element is not None
 
 
-def parse(html_string):
+def parse(html_string, wrapper=Parser):
     """ Parse html with wrapper """
     return Parser(lxml.html.fromstring(html_string))
 
@@ -95,7 +108,7 @@ def to_unicode(obj, encoding='utf-8'):
     return obj
 
 
-def strip_accents(s, pass_symbols=[u'й', u'Й', u'\n']):
+def strip_accents(s, pass_symbols=(u'й', u'Й', u'\n')):
     """ Strip accents from a string """
     result = []
     for char in s:
@@ -110,7 +123,7 @@ def strip_accents(s, pass_symbols=[u'й', u'Й', u'\n']):
     return ''.join(result)
 
 
-def strip_symbols(s, pass_symbols=[u'й', u'Й', u'\n']):
+def strip_symbols(s, pass_symbols=(u'й', u'Й', u'\n')):
     """ Strip ugly unicode symbols from a string """
     result = []
     for char in s:
